<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tool_uploaduser', language 'km', branch 'MOODLE_30_STABLE'
 *
 * @package   tool_uploaduser
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['allowdeletes'] = 'អនុញ្ញាតឲ្យលុប';
$string['allowrenames'] = 'អនុញ្ញាតឲ្យប្ដូរឈ្មោះ';
$string['defaultvalues'] = 'តម្លៃលំនាំដើម';
$string['deleteerrors'] = 'លុបកំហុស';
$string['errors'] = 'កំហុស';
$string['renameerrors'] = 'មានកំហុសក្នុងការប្ដូរឈ្មោះ';
$string['uploadusers'] = 'ផ្ទុកអ្នកប្រើឡើង';
$string['uploadusers_help'] = '<p>Firstly, note that <strong>it is  usually not necessary to import users in bulk</strong> - to keep your own maintenance work down you should first explore forms of authentication that do not require manual maintenance, such as connecting to existing external databases or letting the users create their own accounts. See the Authentication section in the admin menus.</p>
<p>If you are sure you want to import multiple user accounts from a text file, then you need to format your text file as follows:</p>

<ul>
  <li>Each line of the file contains one record</li>
  <li>Each record is a series of data separated by commas</li>
  <li>The first record of the file is special, and contains a list of fieldnames. This defines the format of the rest of the file.
    <blockquote>
      <p><strong>Required fieldnames:</strong> these fields must be included in the first record, and defined for each user</p>
      <p><code>firstname, lastname</code></p>
      <p><strong>Optional fieldnames: </strong>all of these are completely optional. If a values is present for the field in the file, then that value is used; else, the default value for that field is used.</p>
      <p> <code>institution, department, city, country, lang, auth, timezone, idnumber, icq, phone1, phone2, address, url, description, mailformat, maildisplay, htmleditor, autosubscribe, emailstop, deleted</code></p>
      <p><strong>Enrolment fieldnames (optional): </strong>The  course names are the &quot;shortnames&quot; of the courses - if present then the user will be enrolled in those courses. For groups use group name; for roles use id. Group names must be associated to the corresponding courses, i.e. group1 to course1, etc.</p>
      <p><code>course1, group1, type1, role1, course2, group2, type2, role2, etc.</code></p>
    </blockquote>
    </li>
  <li>Commas within the data should be encoded as &amp;#44 - the script will automatically decode these back to commas. </li>
  <li>For Boolean fields, use 0 for false and 1 for true. </li>
  <li>Types are used to tell Moodle whether the user is a student or a teacher if a corresponding course exists (e.g. type2 corresponds to course2). 1 = Student, 2 = Editing Teacher, and 3 = Non-editing Teacher. If type is left blank, or if no course is specified, the user is default to student. </li>
  <li>Note: If a user is already registered in the Moodle user database, this script will return the
      userid number (database index) for that user, and will enrol the user as a student in any of the
      specified courses WITHOUT updating the other specified data.</li>
</ul>
<p>Here is an example of a valid import file:</p>
<p><code>username, password, firstname, lastname, email, lang, idnumber, maildisplay, course1, group1, type1<br />
jonest, verysecret, Tom, Jones, jonest@someplace.edu, en, 3663737, 1, Intro101, Section 1, 1<br />
reznort, somesecret, Trent, Reznor, reznort@someplace.edu, en_us, 6736733, 0, Advanced202, Section 3, 3
</code></p>
<p>The CSV file may contain full informations for some users and use default values for others (use extra commas to corectly associate data to headers). For example, the following file will use default values for username, city and country for user Trent Reznor:</p>
<p><code>username, password, firstname, lastname, country, city<br />
jonest, verysecret, Tom, Jones, RO, Constanta<br />
, somesecret, Trent, Reznor, ,
</code></p>

<h2>Templates</h2>
<p>The default values are processed as templates in which the following codes are allowed:</p>
<ul>
<li><code>%l</code> - will be replaced by the lastname</li>
<li><code>%f</code> - will be replaced by the firstname</li>
<li><code>%u</code> - will be replaced by the username</li>
<li><code>%%</code> - will be replaced by the %</li>
</ul>
<p>Between the percent sign (%) and any code letter (l, f or u) the following modifiers are allowed:</p>
<ul>
<li>minus sign (-) - the information specified by the code letter will be converted to lowercase</li>
<li>plus sign (+) - the information specified by the code letter will be converted to uppercase</li>
<li>a decimal number - the information specified by the code letter will be truncated to that many characters</li>
</ul>

<p>For example, if the firstname is John and the lastname is Doe, the following values will be obtained with the specified templates:</p>
<ul>
<li>%l%f = DoeJohn</li>
<li>%l%1f = DoeJ</li>
<li>%-l%+f = doeJOHN</li>
<li>%-f_%-l = john_doe</li>
<li>http://www.example.com/~%u/ = http://www.example.com/~jdoe/ (if the username is jdoe or %-1f%-l)</li>
</ul>
<p>Template processing is done only on default values, and not on the values retrieved from the CSV file.</p>
<p>In order to create corect Moodle usernames, the username is always converted to lowercase. Moreover, if the &quot;Allow extended characters in usernames&quot; option in the Site policies page is off, characters different to letters, digits, dash (-) and dot (.) are removed.
For example if the firstname is John Jr. and the lastname is Doe, the username %-f_%-l will produce john jr._doe when Allow extended characters in usernames is on, and johnjr.doe when off.</p>
<p>When the &quot;New username duplicate handling&quot; setting is set to Append counter, an auto-increment counter will be append to duplicate usernames produced by the template.
For example, if the CSV file contains the users named John Doe, Jane Doe and Jenny Doe without explicit usernames, the default username is %-1f%-l and New username duplicate handling is set to Append counter, then the usernames produced will be jdoe, jdoe2 and jdoe3.
</p>

<h2>Updating existing accounts</h2>

<p>By default Moodle assumes that you will be creating new user accounts, and skips records where the username matches an existing account. However, if you set "Update existing accounts" to <b>Yes</b>, the existing user account will be updated. </p>

<p>When updating existing accounts you can change usernames as well. Set "Allow renames" to <b>Yes</b> and include in your file a field called <code>oldusername</code>.</p>

<p><b>Warning:</b> any errors updating existing accounts can affect your users badly. Be careful when using the options to update.</p>

<h2>Deleting accounts</h2>
<p>If the <code>deleted</code> field is present, users with value 1 for it will be deleted. In this case, all the fields may be omitted, except for <code>username</code> (which should be present in the CSV file, or a default value for it should be available).</p>
<p>Deleting and uploading accounts could be done with a single CSV file. For example, the following file will add the user Tom Jones and delete the user reznort:</p>
<p><code>username, firstname, lastname, deleted<br />
jonest, Tom, Jones, 0<br />
reznort, , , 1
</code></p>';
$string['useraccountupdated'] = 'បានធ្វើឲ្យអ្នកប្រើទាន់សម័យ';
$string['userdeleted'] = 'បានលុបអ្នកប្រើ';
$string['userrenamed'] = 'បានប្ដូរឈ្មោះអ្នកប្រើ';
$string['userscreated'] = 'បានបង្កើតអ្នកប្រើ';
$string['usersdeleted'] = 'បានលុបអ្នកប្រើ';
$string['usersrenamed'] = 'បានប្ដូរឈ្មោះអ្នកប្រើ';
$string['usersupdated'] = 'បានធ្វើឲ្យអ្នកប្រើទាន់សម័យ';
